#
# spec file for package solid
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5Solid5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           solid
Version:        5.116.0
Release:        1.2
Summary:        KDE Desktop hardware abstraction
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  bison
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5LinguistTools) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Xml) >= %{qt5_version}
BuildRequires:  pkgconfig(libimobiledevice-1.0)
BuildRequires:  pkgconfig(mount)
%if %{?suse_version} >= 1550 || 0%{?sle_version} >= 150400
BuildRequires:  pkgconfig(libplist-2.0)
%else
BuildRequires:  pkgconfig(libplist)
%endif
BuildRequires:  pkgconfig(libudev)

%description
Solid is a device integration framework.  It provides a way of querying and
interacting with hardware independently of the underlying operating system.

%package -n %{lname}
Summary:        KDE Desktop hardware abstraction
Recommends:     %{name}-imports = %{version}
Recommends:     %{name}-tools = %{version}
Recommends:     media-player-info
Recommends:     udisks2
Obsoletes:      libKF5Solid4

%description -n %{lname}
Solid is a device integration framework.  It provides a way of querying and
interacting with hardware independently of the underlying operating system.

%package tools
Summary:        KDE Desktop hardware abstraction

%description tools
Solid is a device integration framework.  It provides a way of querying and
interacting with hardware independently of the underlying operating system.
CLI utilities.

%package imports
Summary:        KDE Desktop hardware abstraction

%description imports
Solid is a device integration framework.  It provides a way of querying and
interacting with hardware independently of the underlying operating system.
QML imports.

%package devel
Summary:        KDE Desktop hardware abstraction: Build Environment
Requires:       %{lname} = %{version}
Requires:       cmake(Qt5Core) >= %{qt5_version}

%description devel
Solid is a device integration framework.  It provides a way of querying and
interacting with hardware independently of the underlying operating system.
Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DWITH_NEW_SOLID_JOB=ON -DWITH_NEW_POWER_ASYNC_API=ON -DWITH_NEW_POWER_ASYNC_FREEDESKTOP=ON -Dlconvert_executable=%{_kf5_libdir}/qt5/bin/lconvert
%cmake_build

%install
%kf5_makeinstall -C build

%fdupes %{buildroot}

%find_lang solid5 --with-qt --without-mo

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}-lang -f solid5.lang

%files -n %{lname}
%license LICENSES/*
%{_kf5_debugdir}/solid.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5Solid.so.5
%{_kf5_libdir}/libKF5Solid.so.5.*

%files tools
%{_kf5_bindir}/solid-hardware5
%{_kf5_bindir}/solid-power

%files imports
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%{_kf5_qmldir}/org/kde/solid/

%files devel
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5Solid/
%{_kf5_libdir}/libKF5Solid.so
%{_kf5_mkspecsdir}/qt_Solid.pri

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Implement solid-hardware monitor mode for property changes
  * Connect UPowerDevice propertyChanged signal to frontend
  * Avoid cache bypass of `UPowerDevice::allProperties`
  * Use values from PropertiesChanged instead of invalidating whole cache
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * Remove some obsolete and incorrect code from UPower and UDisks2 backend
  * Deprecate "Recall" API for batteries
  * Avoid synchronous DBus calls for devices list
  * Initialize supported interfaces with member initializer list
  * Replace generic UPower QDBusInterface with concrete implementation
  * Remove support for UPower < 0.99
  * Remove invalid Refresh DBus call from UPower backend
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- No code change since 5.103.0
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Remove unused variable 'vendor'
  * Perform some initializations in initialization list
  * Convert uint to enum before passing to switch
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * upower: Support UP_DEVICE_KIND_BLUETOOTH_GENERIC
  * imobiledevice: Check error returned by idevice_new (kde#448329)
  * UDisks2::DeviceBackend add udi in trace when failing to to get prop
  * imobiledevice: Handle events in correct thread
  * imobiledevice: Don't call udiPrefix() from constructor
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Fix the translation folder name
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Add Windows Qt 6 CI
  * Disambiguate expression for MSVC
  * .gitlab-ci.yml: enable static builds
  * FstabStorageAccess: Trim output from (u)mount
  * udisks2: Handle NotAuthorizedCanObtain and NotAuthorizedDismissed
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
  * Add explanation for enum value 'Smb3'.
  * Improve SMB3 filesystem integration.
  * Add Samba's SMB3 filesystem to Solid.
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * [UDisksDeviceBackend] Port introspect to QXmlStreamReader
  * [UDisksDeviceBackend] Remove pointless QDBusInterface
  * udev/cpuinfo_arm: add more Apple part IDs
  * udev/cpuinfo_arm: change Apple part formatting
  * Drop lib prefix when building for Windows (MinGW)
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Require passing tests for the CI to pass
  * avoid segfault if qobject_cast fails
  * upower: Allow displaying Apple Magic Trackpad charge level
  * skip non-FileSystem StorageVolumes in storageAccessFromPath
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- No code change since 5.94.0
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * udev/cpuinfo_arm: Add missing CPU ID
  * Mark as supported on Android
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Recognize fuse.gocryptfs mounts as devices like we do for cryfs
    and encfs (kde#452070)
  * Add git blame ignore file
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Use enum in switch instead of raw int
  * Add Qt6 Android CI
  * udisks backend: Add UD2_DBUS_PATH_BLOCKDEVICES and use more constants
  * udev: Do not ignore joysticks
  * Check executables exist in PATH before passing them to QProcess
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Convert some connect to new signature style
  * [UDisks2 Backend] Don't do media check for loop devices
  * Fix enum predicate comparison with Qt6
  * [upower] Properly round up battery's capacity (kde#448372)
  * Add CI qt6 support
  * [UPower Backend] Check for Bluez for any unknown battery type
  * [UDisks2] Ignore file systems mounted with x-gdu.hide option
* Fri Jan 28 2022 Antonio Larrosa <alarrosa@suse.com>
- Also use libplist-2.0 in SLE15-SP4/Leap 15.4
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * udisks backend: don't assume /etc/mtab is not present
  * Remove trailing \x00 from string returned by Q6File::decodeName()
  * Change the build system to enable building with Qt6
  * devicenotifier.h: Fix typo
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Allow udisks2 and upower backends to be disabled with environment variables
  * Add device description for storage medium without size
  * Config.cmake: Lookup LibMount when building statically
  * Add support for graphics tablet batteries
  * [upower] Consider audio devices and generic bluetooth devices to be batteries (kde#445141)
  * [upower] Add new device types
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Fix "unused variable" warning when building without libmount.
  * Fix "unused variable" warning when building on FreeBSD.
  * Implement ARM specific CPU info
  * Add FreeBSD CI
  * Add Android CI
  * Fix compiling on CentOS 7 (broken by clang-format)
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * Add support for static builds
  * support extracting cpu model on ppc64
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * We can use directly std::as_const
  * Port QStringRef (deprected) to QStringView
  * autotests: avoid failure on Linux CI
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * predicate: add an example predicate
  * autotests: test the predicate-parser
  * Use qstrcmp instead of strcmp
  * Remove the HAL backend; HAL is long gone.
  * Udev client: replace a warning message with a debug one (kde#425178)
  * Enable bsdisks_extensions from FreeBSD on OpenBSD
  * Enable OpenBSD UDisk2 support
  * Port framework away from LGPL-2.0-only
- Drop upstream patch:
  * 0001-Use-qstrcmp-instead-of-strcmp.patch
* Thu Jul 22 2021 Luca Beltrame <lbeltrame@kde.org>
- Add libmount to BuildRequires to enable support for bind mounts
- Add upstream patch 0001-Use-qstrcmp-instead-of-strcmp.patch
  to fix potential crashes in dolphin and plasmashell with
  libmount support enabled in Solid
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Add a minimum version to find_package(BISON)
  * Add missing include
  * Find the base mount point of a partition that has bind mounts (kde#349617)
  * UDisks backend: improve the description of volume and storage devices (kde#410891)
  * cmake: drop unused UDEV_HAVE_GET_SYSATTR_LIST_ENTRY cmakedefine01
  * cmake: drop unused EXPERIMENTAL_BSDISKS cmakedefine01
* Wed Jun 16 2021 Wolfgang Bauer <wbauer@tmo.at>
- Enable imobiledevice backend on Leap as well
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Enable imobiledevice backend
- More specific file lists
- Include licenses only in library package
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Ensure inherited PIMPL instances are properly destructed
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Allow building some tests without DBus
  * Do not search for DBus on Windows & Mac
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Run clang-format
  * Prevent clang-format uglification
  * Add clang-format pre-commit hook
  * Add trailing comma to enum
  * Minor: Port some sources to nullptr
  * Fix build under Qt 5.15
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Adding isEncrypted method to AccessStorage
  * solid-hardware: demarshall DBus types for nonportableinfo
  * [UDisks2] Correctly demarshall QDbusObjectPath in `isEncryptedCleartext`
  * Add .gitlab-ci.yml for Solid CI
  * Predicate Parser: fix deprecated directive
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * CMake: use configure_file() to ensure noop incremental builds
  * [Fstab] Ignore docker overlay mounts (kde#422385)
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Remove ifdefs, we require Qt 5.14 now
  * [Try to] fix Windows build now that we require Qt 5.14
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Include errno.h for EBUSY/EPERM
  * FstabBackend: return DeviceBusy where umount failed on EBUSY (kde#411772)
  * Fix detection of recent libplist and libimobiledevice
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Add support for sshfs to the fstab backend
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * CMake: Use pkg_search_module when looking for plist
  * Fix imobiledevice backend: Check API version for DEVICE_PAIRED
  * Fix imobiledevice backend build
  * Add Solid backend using libimobiledevice for finding iOS devices
  * Use QHash for mapping where order is not needed
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- No code change since 5.74.0
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Too many changes to list here.
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Clear m_deviceCache before introspecting again (kde#416495)
  * Use KF-standardized Qt logging categories
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Enable UDisks2 backend on FreeBSD unconditionally.
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Make Solid::Ifaces::Device::displayName virtual
  * Add a QString Solid::Device::displayName,
    used in Fstab Device for network mounts
  * Port away from deprecated Qt Methods
  * [DeviceManager] Port one foreach to range-for
  * [Solid] Port foreach to range-for
  * [Solid] Port foreach to range/index for
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * [Solid] Port foreach to range/index for
  * [FakeCdrom] Add a new UnknownMediumType enumerator to MediumType
  * [Solid] Replace foreach (deprecated) with range/index for
  * [FstabWatcher] Fix loosing of fstab watcher
  * [Fstab] Do not emit deviceAdded twice on fstab/mtab changes
  * [FstabWatcher] Use static QStringLiteral instead of macro
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * [Fstab] Ensure uniqueness for all filesystem types
  * Samba: Ensure to differenciate mounts sharing the same source (kde#418906)
  * Solid: Convert license headers to SPDX expressions
  * hardware tool: define syntax via syntax arg
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Fix inverted logic in IOKitStorage::isRemovable
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Add signals for udev events with actions bind and unbind
  * [Solid] Port away from deprecated QList methods
  * Clarify referencing of DeviceInterface
  * [Solid] Port QRegExp to QRegularExpression
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Remove endl. qCritical/qDebug already adds a endl.
  * Clean up unnecessary code
  * Display first / in mounted storage access description
  * Port QSet::toList deprecated method
  * Remove unused header from QtWidgets
  * Fix build on BSD
  * Port solid from Qt5::Widgets to Qt5::Gui
  * Ensure mounted nfs filesystems matches their fstab declared counterpart (kde#406242)
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * [udisks2] fix media change detection for external optical drives (kde#394348)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Don't build static library when BUILD_TESTING=OFF
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Mark technology propertie as constant to avoid warning
  * fstab: include QThreadStorage in all cases
  * Use directly QElapsedTimer
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Make battery serial property constant
  * Only build tests when DBus is available
  * Expose technology property in battery interface
  * Remove unused includes
- Replace pkgconfig(Qt5Foo) with cmake(Qt5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Make sure solid backends are reentrant
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * [Fstab] Select appropriate icon for home or root directory
  * [Fstab] Show mounted "overlay" filesystems
  * Install in new logging directory when we use kf5 5.59.0
  * [UDev Backend] Narrow device queried for
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Use new syntax
  * tests: build some tests depending on the used backend
  * Refactor the way device backends are built and registered
  * Remove deprecated method qVariantFromValue->QVariant::fromValue
  * [Fstab] Use folder-decrypted icon for encrypting fuse mounts
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * [Fstab] Add support for non-network filesystems
  * [FsTab] Add cache for device file system type
  * [Fstab] Preparatory work for enabling filesystems beyond NFS/SMB
  * Fix no member named 'setTime_t' in 'QDateTime' error while building (kde#405554)
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Allow building without UDev on Linux
  * Only get clearTextPath when used
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Hopefully fix compilation on Windows after commit c9a135579431
  * It compile fine against qt5.13 without deprecated method
  * Bring FindUDev.cmake up to ECM standards
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Build without D-Bus on Android
  * delete copy constructor and assignment operator of some internal classes
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * [UDisks2] Use MediaRemovable to determine if media can be ejected
  * Use nullptr in more places
  * lexer: disable input and unput functions
  * Use nullptr in more places
  * Support Bluetooth batteries
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Remove virtual keyword
  * Remove Qt prefix include
  * Fix root disk icon change so that it doesn't erroneously change other icons
  * Normalize signal/slot
  * Use the new `drive-harddisk-root` icon for the root volume
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * [solid-hardware5] List icon in device details
  * Add DEFAULT_SEVERITY
  * [UDisks2] Power down drive on remove if supported (kde#270808)
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Don't show an emblem for mounted disks, only unmounted disks
  * [Fstab] Remove AIX support
  * [Fstab] Remove Tru64 (__osf__) support
  * Create and install solid.categories for kdebugsettings
  * [Fstab] Add support for categorized logging
  * [Fstab] Show non-empty share name in case root fs is exported (kde#395562)
  * API dox: fix @note, to be used without trailing :
  * Avoid potential detach on range-loops with non-const Qt containers
  * Use QString's multi-arg with multiple string args
  * Prefer provided drive label for loop devices as well
  * Fix minor EBN issues
  * Fix minor EBN issues
  * Avoid division by zero
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * solid/udisks2: Add support for categorized logging
  * [Windows Device] Show device label only if there is one
  * Force reevaluation of Predicates if interfaces are removed
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Fix device label with unknown size
  * Use more nullptr
  * Use consistently override
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use override
  * [FStab Handling] Clean up process running by using lambdas
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Update mount point after mount operations (kde#370975)
  * Invalidate property cache when an interface is removed
  * Avoid creating duplicate property entries in the cache
  * [UDisks] Optimize several property checks
  * [UDisks] Correct handling of removable file systems (kde#391706)
- Dropped patches, now upstream:
  * Update-mount-point-after-mount-operations.patch
  * UDisks-Correct-handling-of-removable-file-systems.patch
* Wed May  2 2018 wbauer@tmo.at
- Add Update-mount-point-after-mount-operations.patch to fix
  spurious errors when trying to open an unmounted disk/device in
  file manager (kde#370975)
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Introduce GamingInputBattery type
  * Fix build on Android
  * Use recently introduced UP enums
  * add gaming_input devices and others to Battery
  * Adding Battery Devices EnumAdding Battery Devices Enum
  * [UDevManager] Also explicitly query for cameras
  * [UDevManager] Already filter for subsystem before querying
* Mon Apr  9 2018 wbauer@tmo.at
- Add UDisks-Correct-handling-of-removable-file-systems.patch to
  fix problems with mounting removable devices introduced by the
  previous fix for Auto-mount (kde#391706, kde#389479)
* Sat Apr  7 2018 fabian@ritter-vogt.de
- Add udisks2 recommends
- Use %%license
- Remove unnecessary ldconfig calls for -imports
- Remove unnecessary %%requires_ge
- Clean .spec file
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * fix a leak and incorrect nullptr check in DADictionary.
  * [UDisks] Fix auto-mount regression (kde#389479)
  * [UDisksDeviceBackend] Avoid multiple lookup
  * Mac/IOKit backend: support for drives, discs and volumes
- Dropped patches, now upstream:
  * Fix-auto-mount-regression.patch
* Sat Feb 24 2018 wbauer@tmo.at
- Add Fix-auto-mount-regression.patch to fix broken "Automount on
  login" with solid 5.43.0 (kde#389479)
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * unset maintainer
  * [UDisks] Only ignore non-user backing file if it is known (kde#389358)
  * [UDisks] Ignore non-user mounts (kde#379516)
  * [UDisks Device] Show loop device with their backing file name and icon
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Fix minor CMake warning
  * Remove cmake warning
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Faster UDevManager::devicesFromQuery
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Reduce QString creation in Udev checking
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * [solid/fstab] Add support for x-gvfs style options in fstab
  * [solid/fstab] Swap vendor and product properties, allow i18n of description
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * None
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Require sys/types.h for dev_t unconditionally.
  * Use more nullptr
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * hal: use Q_DECL_OVERRIDE
  * cmake: build udisks2 backend on FreeBSD only when enabled
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Revert "Fix incorrect definition of major(3)/minor(3) macros." This patch is part of a series which broke the build on MSVC.
  * Revert "Adding files missing from last commit." This patch breaks the build for MSVC.
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Adding files missing from last commit.
  * Fix incorrect definition of major(3)/minor(3) macros.
  * cmake: stop documenting non-existing variables
  * Add include that is needed in msys2
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Minor: Fix API doc
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * [UDisks 2 Device] Add description for Floppy Disk
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * winutils_p.h: Restore compatibility with WinXP SDK
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Fix unstable ordering of query results yet again
  * Add a CMake option to switch between HAL and UDisks
    managers on FreeBSD
  * Make UDisks2 backend compile on FreeBSD
    (and, possibly, other UNIXes)
  * Windows: Don't display error dialogs (kde#371012)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Always update the Predicate parser from yacc/lex sources
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Fix check that CPU is valid
  * Handle reading /proc/cpuinfo for Arm processors
  * Find CPUs by subsystem rather than driver
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Thu May 19 2016 alarrosa@suse.com
- The media-player-info package is not required anymore, but recommended.
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Refresh the battery properties upon resume
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Added energyFull and energyFullDesign to Battery
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Enable fstab and upower backends on FreeBSD
  * Power: Add aboutToSuspend signal
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Fix warning: No such signal org::freedesktop::UPower::Device
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * New freedesktop backend, replacing the upower/udev/systemd backends
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Split command line utilities to a separate tools subpackage
- Enable WITH_NEW_POWER_ASYNC_FREEDESKTOP CMake option
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Thu Aug  7 2014 toddrme2178@gmail.com
- Add media-player-info dependency for media player
  identification.  It is a runtime dependency that was not listed
  as a dependency at all.
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Harden required Qt5 libs versions
- Pass the location of lconvert executable
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
- Drop 0001-Add-timeToFull-timeToEmpty-recall-notice-and-FullyCh.patch,
  merged upstream
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Build new API (pass WITH_NEW_SOLID_JOB=ON WITH_NEW_POWER_ASYNC_API
  flags to CMake)
- Added libqt5-linguist-devel BuildRequires
- Add baselibs.conf
- Add 0001-Add-timeToFull-timeToEmpty-recall-notice-and-FullyCh.patch,
  improves API for Battery handling
* Tue May 27 2014 hrvoje.senjan@gmail.com
- Build with pkgconfig(libudev), not pkgconfig(udev)
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
- No longer move solid-hardware binary by hand, it's now fixed
  upstream correctly
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init solid package
